# run via [tes3cmd modify -program ThisFile.pl]

my $output = open_for_output('AC_Updater.esp');
print $output make_header({
    author => 'abot, g7, stuporstar, tes3cmd',
    description => 'Animated Containers Updater',
});


my %anim = (                    # script          # model
    'contain_barrel_01'      => ['ac_barrel',     'anim_barrel_01'],
    'contain_barrel10'      => ['ac_barrel',     'anim_barrel_02'],
    'contain_chest10'        => ['ac_chest',      'anim_chest10'],
    'contain_chest_large_01' => ['ac_chest_large', 'anim_chest_large'],
    'anim_chest_large' => ['ac_chest_large', 'anim_chest_large'],
    'contain_chest_small_01' => ['ac_chestsmall', 'anim_chest_small_01'],
    'contain_chest_small_02' => ['ac_chestsmall', 'anim_chest_small_02'],
    'contain_com_basket_01'  => ['ac_basket',     'anim_basket'],
    'contain_com_chest_01'   => ['ac_chest',      'anim_com_chest_01'],
    'contain_com_chest_02'   => ['ac_chest',      'anim_com_chest_02'],
    'contain_com_closet_01'  => ['ac_closet',     'anim_com_closet_01'],
    'contain_com_cupboard'   => ['ac_cupboard',   'anim_cupboard'],
    'contain_com_drawers'    => ['ac_drawer',     'anim_com_drawers_01'],
    'contain_com_hutch_01'   => ['ac_cupboard',   'anim_hutch'],
    'contain_com_sack_01'    => ['ac_sack',       'anim_sack_01'],
    'contain_com_sack_02'    => ['ac_sack',       'anim_sack_02'],
    'contain_com_sack_03'    => ['ac_sack',       'anim_sack_03'],
    'contain_couldron10'     => ['ac_cauldron',   'anim_cauldron'],
    'contain_crate_01'       => ['ac_crate',      'anim_crate_01'],
    'contain_crate_02'       => ['ac_crate',      'anim_crate_02'],
    'contain_daedric_chest_01' => ['ac_daedric_chest', 'anim_daedric_chest'],
    'anim_daedric_chest' => ['ac_daedric_chest', 'anim_daedric_chest'],
    'contain_de_chest_01'    => ['ac_chest',      'anim_de_chest_01'],
    'contain_de_chest_02'    => ['ac_chest',      'anim_de_chest_02'],
    'contain_de_closet_01'   => ['ac_closet',     'anim_de_closet_01'],
    'contain_de_closet_02'   => ['ac_closet',     'anim_de_closet_02'],
    'contain_de_crate_logo'  => ['ac_crate',      'anim_cratelogo'],
    'contain_de_desk_01'     => ['ac_drawer_de',  'anim_de_desk_01'],
    'contain_de_drawers_01'  => ['ac_drawer',     'anim_de_drawers_01'],
    'contain_de_drawers_02'  => ['ac_drawer_de',  'anim_de_drawers_02'],
    'contain_de_table_01'    => ['ac_drawer_de',  'anim_de_table_01'],
    'contain_de_table_02'    => ['ac_drawer_de',  'anim_de_table_02'],
    'contain_dwrv_barrel00'  => ['ac_dw_barrel',  'anim_dw_barrel_01'],
    'contain_dwrv_barrel10'  => ['ac_dw_barrel',  'anim_dw_barrel_02'],
    'contain_dwrv_chest00'   => ['ac_dw_chest',   'anim_dwrv_chest00'],
    'contain_dwrv_chest10'   => ['ac_dw_chest',   'anim_dwrv_chest10'],
    'contain_dwrv_closet00'  => ['ac_dw_closet',  'anim_dw_closet'],
    'contain_dwrv_desk00'    => ['ac_dw_drawer',  'anim_dw_desk'],
    'contain_dwrv_drawers00' => ['ac_dw_drawer',  'anim_dw_drawers'],
    'contain_dwrv_table00'   => ['ac_dw_drawer',  'anim_dw_table'],
    'contain_pot_01'         => ['ac_pot',        'anim_pot'],
    'contain_urn_01'         => ['ac_urn',        'anim_urn_01'],
    'contain_urn_02'         => ['ac_urn',        'anim_urn_02'],
    'contain_urn_03'         => ['ac_urn',        'anim_urn_03'],
    'contain_urn_04'         => ['ac_urn',        'anim_urn_04'],
    'contain_urn_05'         => ['ac_urn',        'anim_urn_05'],
    'furn_cabinet10'         => ['ac_drawer',     'anim_cabinet10'],
    'furn_dwrv_cabinet00'    => ['ac_dw_drawer',  'anim_dw_cabinet'],
    'furn_shell00'           => ['ac_kollop',     'anim_kollop_01'],
    'furn_shell10'           => ['ac_kollop',     'anim_kollop_02'],
    'furn_shell20'           => ['ac_kollop',     'anim_kollop_03'],
);


my %skip = map {lc $_, 1} (
    "AC_Updater.esp",
    "AlchemyFilter.esp",
    "fogpatch.esp",
    "GMST Fix.esp",
    "GMST Vaccine.esp",
    "Mashed Lists.esp",
    "Merged_Dialogues.esp",
    "Merged_Leveled_Lists.esp",
    "multipatch.esp",
    "Texture Fix - Bloodmoon 1.1.esm",
    "Texture Fix 2.0.esm",
); # these ESP have no containers


open(my $log, '>'. 'AC_Updater.log');


printf $log "DATADIR: $DATADIR\n";
printf $log "$_\n" for $T3->load_order;


my %seen;
for my $plugin (reverse $T3->load_order) {
    next if exists $skip{lc $plugin};

    my $input = open_for_input($plugin);
    while (my $record = TES3::Record->new_from_input($input, undef, $plugin)) {
        next if $record->rectype ne 'CONT';

        my $id = $record->decode->id;
        next if exists $seen{$id}; $seen{$id}++;

        next if $record->get('SCRI')
             or $record->get('MODL', 'model') !~ /([^\\]+)\.nif$/i;

        eval {
            my ($script, $model) = @{ $anim{lc $1} };
            printf $log "ID: %-31s SCRIPT: %-15s MODEL: %s\n", $id, $script, $model;

            $record->set({f=>'model'}, "ac\\$model.nif");
            $record->append(CONT::SCRI->new({script=>$script}));
            $record->encode->write_rec($output);
        }
    }
}


exit